@@ -175,7 +175,7 @@ forward.search <- function(data, model, criteria = c('GOF', 'mah'),
 		RMR[i+1] <- sqrt(2*sum(((basemodels[[i+1]]$R - Rhat)^2) /
 			(ncol(Rhat)*(ncol(Rhat) + 1))))
 		ret <- list(GOF=GOFstat, RMR=RMR, gCD=Cooksstat, ord=orderentered)
-	} else if(class(model) == "semmod"){
+	} else if(is(model, "semmod")){
 	    STATISTICS <- myApply(matrix(1:n.subsets), 1, function(i, data, Samples, model){
             tmpdat <- data[Samples[ ,i], ]
 	        samplesemMod <- try(sem::sem(model, cov(tmpdat), nrow(tmpdat), ...), TRUE)
@@ -252,7 +252,7 @@ forward.search <- function(data, model, criteria = c('GOF', 'mah'),
 	    C <- basemodels[[i+1]]$S
 	    RMR[i+1] <- sqrt(2*sum(((C - Chat)^2) /	(ncol(C)*(ncol(C) + 1))))
 	    ret <- list(GOF=GOFstat, RMR=RMR, gCD=Cooksstat, ord=orderentered)
-	} else if(class(model) == "character"){
+	} else if(is.character(model)){
 	    STATISTICS <- myApply(matrix(1:n.subsets), 1, function(i, data, Samples, model){
 	        tmpdat <- data[Samples[ ,i], ]
 	        samplesemMod <- try(lavaan::sem(model, data=tmpdat, ...), TRUE)
