@@ -5,10 +5,10 @@ test_that('forward.search run', {
 
     #Exploratory
     nfact <- 3
-    FS <- forward.search(holzinger, nfact, print.messages = FALSE)
+    FS <- forward.search(holzinger, nfact, print.messages = FALSE, )
     expect_is(FS, 'forward.search')
     expect_is(plot(FS), 'trellis')
-    expect_equal(FS$GOF[c(1, length(FS$GOF))], c(3.717805, 26.293829), tolerance = 1e-5)
+    expect_equal(FS$GOF[c(1, length(FS$GOF))], c(6.079796, 26.293829), tolerance = 1e-5)
 
     #-------------------------------------------------------------------
     suppressMessages(model <- sem::specifyModel(file='sem-model/sem-model.txt', quiet=TRUE))
@@ -16,7 +16,7 @@ test_that('forward.search run', {
     expect_is(FS.outlier, 'forward.search')
     expect_is(plot(FS.outlier), 'trellis')
     expect_equal(FS.outlier$GOF[c(1, length(FS.outlier$GOF))],
-                 c(34.64542, 161.01480), tolerance = 1e-5)
+                 c(25.69686, 161.01480), tolerance = 1e-5)
 
     #---- lavaan
     model <- 'F1 =~  Remndrs + SntComp + WrdMean
@@ -27,6 +27,6 @@ test_that('forward.search run', {
     expect_is(FS.outlier, 'forward.search')
     expect_is(plot(FS.outlier), 'trellis')
     expect_equal(FS.outlier$GOF[c(1, length(FS.outlier$GOF))],
-                 c(26.96743, 111.39844), tolerance = 1e-5)
+                 c(29.22207, 111.39844), tolerance = 1e-5)
 
 })
\ No newline at end of file
